@@ -3,7 +3,7 @@ import DAQmxFunctions
 from DAQmxFunctions import *
 from DAQmxCallBack import *
 
-# Create a list of the name of the function that uses TastHandle as the firs argument
+# Create a list of the name of the function that uses TastHandle as the first argument
 # All the function of this list will be converted to method of the task object
 # The name of the method will be the same name as the name of the DAQmx function without the 
 # the DAQmx in front of the name
@@ -12,29 +12,32 @@ task_function_list = [name for name in function_dict.keys() if \
                  (function_dict[name]['arg_type'][0] is TaskHandle) and\
                  'task' in function_dict[name]['arg_name'][0]]
 
+# Remove ClearTask in task_functon_list
+task_function_list = [name for name in task_function_list if name not in ['DAQmxClearTask']]
+
 
 class Task():
     def __init__(self):
-        taskHandle = TaskHandle(0)
-        DAQmxCreateTask(b"",byref(taskHandle))
-        self.taskHandle = taskHandle
-        self.__cleared = False #Flag to clear the task only once
+        self.taskHandle = TaskHandle(0)
+        DAQmxCreateTask(b"",byref(self.taskHandle))
     def __del__(self):
         """ Clear automatically the task to be able to reallocate resources """ 
         # Clear the task before deleting the object
         # If the task as already been manually cleared, nothing is done
-        # This prevent to clear a task that has a Handle attributes to a new task
+        # This prevent to clear a task that has a Handle attributed to a new task
         # See this example
         # a = Task(), ..., a.ClearTask(), b = Task(), del(a)
         # b has the same taskHandle as a, and deleting a will clear the task of b   
         try: 
-            if not self.__cleared:
-                self.ClearTask()
+            self.ClearTask()
         except DAQError:
             pass
     def ClearTask(self):
-        DAQmxClearTask(self.taskHandle)
-        self.__cleared = True
+        if self.taskHandle.value != 0:
+            try:
+                DAQmxClearTask(self.taskHandle)
+            finally:
+                self.taskHandle.value = 0
     def __repr__(self):
         return "Task number %d"%self.taskHandle.value
     def AutoRegisterEveryNSamplesEvent(self, everyNsamplesEventType,nSamples,options, name='EveryNCallback'):
@@ -63,7 +66,7 @@ class Task():
         With this method you can register a method of the class Task as a callback function. 
         The parameter options is the same as the DAQmxRegisterDoneEvent parameters
         
-        The method registered as one parameter, status        
+        The method registered has one parameter : status        
         """
         self_id = create_callbackdata_id(self)
         # Define the python function
@@ -94,26 +97,17 @@ class Task():
         self.SignalCallback_C = DAQmxSignalEventCallbackPtr(SignalCallback_py)
         # Register the function
         self.RegisterSignalEvent(signalID, options, self.SignalCallback_C, self_id)
+    # Dynamically creates the method from the task_function_list
+    for function_name in task_function_list:
+        name = function_name[5:] # remove the DAQmx in front of the name
+        func = getattr(DAQmxFunctions, function_name)
+        arg_names = function_dict[function_name]['arg_name']
+        doc = 'T.%s(%s) -> error.' %(name, ', '.join(arg_names[1:]))
+        cmd = """def {0}(self, {1}):
+        "{3}"
+        {2}(self, {1})"""
+        exec(cmd.format(name, ', '.join(arg_names[1:]), function_name, doc))    
+    del function_name, name, func, arg_names, doc
 
 
-# Remove ClearTask in task_functon_list
-task_function_list = [name for name in task_function_list if name not in ['DAQmxClearTask']]
-
-def _create_method(func):
-    def _call_method(self,*args):
-        return func(self.taskHandle, *args)
-    return _call_method
-
-
-for function_name in task_function_list:
-    name = function_name[5:] # remove the DAQmx in front of the name
-    func = getattr(DAQmxFunctions, function_name)
-    arg_names = function_dict[function_name]['arg_name']
-    taskfunc = _create_method(func)
-    taskfunc.__name__ = name
-    taskfunc.__doc__ = 'T.%s(%s) -> error.' % \
-            (name, ', '.join(arg_names[1:]))
-    setattr(Task, name, taskfunc)
-
-# Clean private functions from namespace
-del _create_method
+del task_function_list
\ No newline at end of file
